# unitorch.cli.models.mbart

## MBartProcessor

!!! tip
    **`core/process/mbart`** is the section for configuration of MBartProcessor.

::: unitorch.cli.models.mbart.MBartProcessor

## MBartForGeneration

!!! tip
    **`core/model/generation/mbart`** is the section for configuration of MBartForGeneration.

::: unitorch.cli.models.mbart.MBartForGeneration
